aboutsummaryrefslogtreecommitdiffstats
path: root/boot.php
diff options
context:
space:
mode:
authorredmatrix <redmatrix@redmatrix.me>2015-05-05 03:56:10 -0700
committerredmatrix <redmatrix@redmatrix.me>2015-05-05 03:56:10 -0700
commita3c37f145817407df28e9ffea6a83a6cd2b31cdd (patch)
tree86a1b3a9497fd6a67d57ac2ae081d1530b4ea30f /boot.php
parent57fcfc9398356bc2223341676500a77b607e9bd9 (diff)
downloadvolse-hubzilla-a3c37f145817407df28e9ffea6a83a6cd2b31cdd.tar.gz
volse-hubzilla-a3c37f145817407df28e9ffea6a83a6cd2b31cdd.tar.bz2
volse-hubzilla-a3c37f145817407df28e9ffea6a83a6cd2b31cdd.zip
first pass name change
Diffstat (limited to 'boot.php')
-rwxr-xr-xboot.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/boot.php b/boot.php
index 1eebaf1ec..647f19616 100755
--- a/boot.php
+++ b/boot.php
@@ -80,9 +80,9 @@ $DIRECTORY_FALLBACK_SERVERS = array(
'https://zothub.com',
'https://zotid.net',
'https://red.zottel.red',
- 'https://redmatrix.info',
+ 'https://hubzilla.info',
'https://my.federated.social',
- 'https://redmatrix.nl'
+ 'https://hubzilla.nl'
);
@@ -2179,7 +2179,7 @@ function construct_page(&$a) {
}
/**
* @brief Returns RedMatrix's root directory.
*
* @return string
*/
@@ -2287,7 +2287,7 @@ function z_check_cert() {
/**
* @brief Send email to admin if server has an invalid certificate.
*
* If a RedMatrix hub is available over https it must have a publicly valid
* certificate.
*/
function cert_bad_email() {
@@ -2179,7 +2179,7 @@ function construct_page(&$a) {
}
/**
- * @brief Returns RedMatrix's root directory.
+ * @brief Returns Hubzilla's root directory.
*
* @return string
@@ -2287,7 +2287,7 @@ function z_check_cert() {
* @brief Send email to admin if server has an invalid certificate.
*
- * If a RedMatrix hub is available over https it must have a publicly valid
+ * If a Hubzilla hub is available over https it must have a publicly valid
* certificate.
*/